from .download import download_zip, download_file
from pathlib import Path
down_path = Path(__file__).parent
xz_url = "addons_file"+"/"+down_path.name+"/"
download_zip(xz_url + "glared.zip",down_path)

frame_current = 0
bl_info = {
    "name": "Glared",
    "author": "Beniamino Della Torre, Alfonso Annarumma",
    "version": (1, 2, 1),
    "blender": (3, 5, 0),
    "location": "View3D > Toolbox",
    "description": "Create Composite FX in node Editor ",
    "warning": "",
    "wiki_url": "",
    "category": "Node",
    }
import importlib

if "bpy" in locals():

    importlib.reload(ui)

    importlib.reload(function)

    importlib.reload(operators)



else:

    from . import (ui, operators,function)

import bpy
import os
from bpy.types import WindowManager
from bpy.types import Menu, Panel, UIList, PropertyGroup, Operator, AddonPreferences
from bpy.props import EnumProperty, StringProperty, BoolProperty, IntProperty, CollectionProperty, FloatProperty, FloatVectorProperty, PointerProperty
from bl_operators.presets import AddPresetBase
from bpy.app.handlers import persistent



from mathutils import Vector
from .translation.translate import GetTranslationDict



class GlaredPreferences(AddonPreferences):
    # this must match the addon name, use '__package__'
    # when defining this in a submodule of a python package.
    bl_idname = __package__
    glare_alert: BoolProperty(default=False, name="Don't show again", description="Remove Warning")
    multy_scene_warning: BoolProperty(default=False, name="Don't show again", description="Remove Warning")

    def draw(self, context):
        row = self.layout.row()
        row.operator(operators.SCENE_OT_GlaredResetWarning.bl_idname)

class SCENE_OT_glared_composite_preset(AddPresetBase, Operator):
    """Save Current Settings"""
    bl_idname = 'glared.add_preset_composite'
    bl_label = 'Save current Composite Properties into a Preset'
    preset_menu = 'SCENE_MT_GlaredPresetsComposite'
    # Common variable used for all preset values

    preset_defines = [
        'node_group = bpy.context.scene.node_tree.nodes["Glared"]',
        'node_light_boost = bpy.context.scene.node_tree.nodes["Glared"].node_tree.nodes["Bright/Contrast"]',

    ]

    # Properties to store in the preset

    preset_values = [
        'node_group.inputs[1].default_value',
        'node_group.inputs[2].default_value',
        'node_group.inputs[3].default_value',
        'node_group.inputs[4].default_value',
        'node_group.inputs[5].default_value',
        'node_group.inputs[6].default_value',
        'node_group.inputs[7].default_value',
        'node_group.inputs[8].default_value',
        'node_group.inputs[9].default_value',
        'node_group.inputs[10].default_value',
        'node_group.inputs[11].default_value',
        'node_group.inputs[12].default_value',
        'node_group.inputs[13].default_value',
        'node_group.inputs[14].default_value',
        'node_group.inputs[15].default_value',
        'node_group.inputs[16].default_value',
        'node_group.inputs[17].default_value',
        'node_group.inputs[18].default_value',
        'node_group.inputs[19].default_value',
        'node_group.inputs[20].default_value',
        'node_light_boost.mute',


    ]
    # Directory to store the presets
    preset_subdir = 'glared'



class SCENE_MT_GlaredPresetsComposite(Menu):
    bl_label = 'Presets'
    preset_subdir = 'glared'
    preset_operator = 'script.execute_preset'
    draw = Menu.draw_preset




def light_boost_update(self, context):
    scene = context.scene
    glared = "Glared"
    if scene.node_tree:
        nodes = scene.node_tree.nodes
        if glared in nodes:
            glared_node = nodes[glared]

            node = glared_node.node_tree.nodes['Bright/Contrast']
            node.mute = not self.light_boost

def active_node(self, context):
    scene = context.scene
    glared = "Glared"
    nodes = scene.node_tree.nodes
    if glared in nodes:
        glared_node = nodes[glared]
        glared_node.mute = not self.active_fx_glared


class SCENE_PG_glaredprop(PropertyGroup):

    active_fx_glared : BoolProperty(default = True, name="Switch Realtime FX On/Off", description="Switch Realtime FX On/Off", update=active_node)
    #light_boost : BoolProperty(default = True, name="Light Boost", description="Add a Light Boost to increase lightness", update=light_boost_update)
    #glare_alert: BoolProperty(default=False, name="Don't show again", description="Remove Warning")





classes = (

            SCENE_PG_glaredprop,

            ui.PANEL_PT_glared,
            GlaredPreferences,
            SCENE_OT_glared_composite_preset,
            SCENE_MT_GlaredPresetsComposite,
            operators.SCENE_OT_Glared_popup_remove_preset,
            operators.SCENE_OT_GlaredCancel,
            operators.SCENE_OT_Glared_RealtimeFX,
            operators.SCENE_OT_Glared_RemoveRealtimeFX,
            operators.SCENE_OT_Glared_ExportPreset,
            operators.SCENE_OT_Glared_ImportPreset,
            operators.SCENE_OT_GlaredResetWarning,




)


def menu_func_import_preset(self, context):
    self.layout.operator(operators.SCENE_OT_Glared_ImportPreset.bl_idname, text="Import Preset...")
def menu_func_export_preset(self, context):
    self.layout.operator(operators.SCENE_OT_Glared_ExportPreset.bl_idname, text="Export Preset...")

def register():

    from bpy.utils import register_class
    for cls in classes:
        register_class(cls)



    bpy.types.Scene.glaredglobalprop = PointerProperty(type=SCENE_PG_glaredprop)



    # creare la directory dei preset e copiarci dentro il preset
    config_dir = bpy.utils.resource_path('USER')
    my_presets = config_dir+'/scripts/presets/glared'



    SCENE_MT_GlaredPresetsComposite.append(menu_func_import_preset)
    SCENE_MT_GlaredPresetsComposite.append(menu_func_export_preset)
    bpy.app.translations.register(__package__, GetTranslationDict())



def unregister():

    for cls in classes:
        bpy.utils.unregister_class(cls)

    del bpy.types.Scene.glaredglobalprop
    bpy.app.translations.unregister(__package__)


if __name__ == "__main__":
    register()
