import zipfile
import pathlib
import bpy
import os

def unzip_presets(preset_dir, filepath):
    with zipfile.ZipFile(filepath, 'r') as zip_file:
        zip_file.extractall(preset_dir)
    return {'FINISHED'}


def zip_presets(preset_dir, filepath):

    directory = pathlib.Path(preset_dir)

    with zipfile.ZipFile(filepath, mode="w") as archive:
        for preset_path in directory.rglob("*"):
            #print(preset_path)
            archive.write(
                preset_path,
                arcname=preset_path.relative_to(directory)
            )


    return {'FINISHED'}

def import_composite_node(node_name):

    path = config_dir = os.path.dirname(__file__) + "/glared/"

    blendfile = "NodeGroupFlared" + ".blend"

    filepath = path + blendfile

    with bpy.data.libraries.load(filepath) as (data_from, data_to):
        data_to.node_groups = [node_name]


def add_composite_node_group(context, node_name):
    scene = context.scene
    # attivo i nodi in scena
    scene.use_nodes = True
    scene.render.use_compositing = True
    data = bpy.data

    nodes = scene.node_tree.nodes
    links = scene.node_tree.links
    composite = None

    # cerchiamo il nodo di output, in caso non ci sia ritorniamo un False
    for node in nodes:
        if node.type == "COMPOSITE":
            composite = node
        if node.name == node_name:
            return False
    if composite is None:
        return False

    if not composite.inputs['Image'].links:
        return False

    location = composite.location

    flaredpost = nodes.new("CompositorNodeGroup")
    flaredpost.name = node_name
    flaredpost.node_tree = data.node_groups[node_name]
    flaredpost.location = location

    composite.location.x += 200

    # ricaviamo il soket che va nel nodo immagine del composite out:
    if composite.inputs['Image'].links:
        from_socket = composite.inputs['Image'].links[0].from_socket

        links.new(from_socket, flaredpost.inputs[0])

    links.new(flaredpost.outputs[0], composite.inputs[0])

    composite.select = True
    nodes.active = composite

    context.scene.node_tree.nodes.update()
    scene.use_nodes = False
    scene.render.use_compositing = False
    scene.use_nodes = True
    scene.render.use_compositing = True
    scene.node_tree.update_tag()
    scene.update_tag()
    if "Compositing" in data.screens:
        data.screens['Compositing'].update_tag()

    return True

def remove_composite_node_group(context,node_name):
    scene = context.scene

    nodes = scene.node_tree.nodes
    links = scene.node_tree.links
    data = bpy.data
    # cerchiamo il nodo
    if node_name in nodes:
        from_socket = None
        to_socket = None
        flaredpost = nodes[node_name]
        # se il nodo è collegato in uscita e in entrata recuperiamo i socket rispettivi
        if flaredpost.inputs['Image'].links:
            from_socket = flaredpost.inputs['Image'].links[0].from_socket
        if flaredpost.outputs['Image'].links:
            to_socket = flaredpost.outputs['Image'].links[0].to_socket


        # rimuoviamo il nodo
        nodes.remove(flaredpost)
        data.node_groups.remove(data.node_groups['Glared'])
        # rifacciamo i collegamenti se i socket erano collegati
        if from_socket and to_socket:
            links.new(from_socket, to_socket)


        context.scene.node_tree.nodes.update()
        scene.use_nodes = False
        scene.render.use_compositing = False
        scene.use_nodes = True
        scene.render.use_compositing = True
        scene.node_tree.update_tag()
        scene.update_tag()
        if "Compositing" in data.screens:
            data.screens['Compositing'].update_tag()


def list_of_prop(node):
    list = []
    for input in node.inputs:

        if input.name == "Image":
            continue
        list.append(input.name)

    return list
